<?php

namespace Drupal\content_workflow_bynder_ui\Plugin\views\field;

use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\node\Plugin\views\field\Path;
use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\ResultRow;
use Drupal\views\ViewExecutable;

/**
 * A handler to provide a field that is completely custom by the administrator.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("content_workflow_bynder_content_link")
 */
class ContentWorkflowBynderContentLink extends Path {

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);

    $this->additional_fields['cwb_id'] = 'cwb_id';
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $cwb_id = $this->getValue($values, 'cwb_id');
    if (is_numeric($cwb_id)) {
      $base_url = 'https://' . \Drupal::config('content_workflow_bynder.settings')
        ->get('content_workflow_bynder_urlkey') . '.content_workflow_bynder.com/item/';
      $url = Url::fromUri($base_url . $cwb_id);
      return Link::fromTextAndUrl($this->t('Open'), $url)->toRenderable();
    }
    else {
      return $this->t('Not available');
    }
  }

}
